@@ -1,8 +1,16 @@
 # -*- coding: utf-8 -*-
+try:
+    import json
+except ImportError:
+    try:
+        import simplejson
+    except:
+        print "You need at least simplejson - http://pypi.python.org/pypi/simplejson - to continue with pypalm"
+        exit()
 
 import os, re
 import codecs
-import json
+
 
 def get_files(current_dir):
     files = []
